@@ -786,7 +786,11 @@ gboolean
 open_file_with_nautilus (GtkWidget * window,
                          const gchar * file)
 {
+	GnomeDesktopItem * ditem;
+ 	GdkScreen * screen;
+	GError *error = NULL;
 	gchar * command;
+	gchar * contents;
 	gchar * escaped;
 
 	escaped = g_shell_quote (file);
@@ -797,11 +801,47 @@ open_file_with_nautilus (GtkWidget * window,
 	                       "--no-default-window ",
 	                       escaped, 
 	                       NULL);
-	gdk_x11_window_set_user_time (window->window, 0);
-	g_spawn_command_line_async (command, NULL);
+			       
+	contents = g_strdup_printf ("[Desktop Entry]\n"
+				    "Name=Nautilus\n"
+				    "Icon=file-manager\n"
+				    "Exec=%s\n"
+				    "Terminal=false\n"
+				    "StartupNotify=true\n"
+				    "Type=Application\n",
+				    command);
+
+	ditem = gnome_desktop_item_new_from_string (NULL,
+	                                            contents,
+	                                            strlen (contents),
+	                                            GNOME_DESKTOP_ITEM_LOAD_NO_TRANSLATIONS ,
+	                                            NULL);
+	
+	if (ditem == NULL) {
+		g_free (contents);
+		g_free (command);
+		g_free (escaped);
+		return FALSE;
+	}
+	
+	screen = gtk_widget_get_screen (window);
+
+	gnome_desktop_item_set_launch_time (ditem, 
+	                                    gtk_get_current_event_time ());
+
+	gnome_desktop_item_launch_on_screen (ditem, NULL, 
+	                                     GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE, 
+					     screen, -1, &error);				
+
+	gnome_desktop_item_unref (ditem);
+	g_free (contents);
 	g_free (command);
 	g_free (escaped);
 
+	if (error) {		
+		g_error_free (error);
+		return FALSE;
+	}
 	return TRUE;
 }
 
@@ -842,6 +882,7 @@ open_file_with_application (GtkWidget * window,
 				}
 				else {
 				 	screen = gtk_widget_get_screen (window);
+					gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
 					gnome_desktop_item_launch_on_screen (ditem, uris, 
 						GNOME_DESKTOP_ITEM_LAUNCH_APPEND_URIS, screen, -1, &error);
 					if (error) {
